local args = { ... };
local LB = args[2];

local _locale = LB.GetLocaleTable(GetLocale());
local _defaultConfig = {
   ConfigVersion = 1.9,
   DisplayToggles = {
      ["ITEM_MOD_DEFENSE_SKILL_RATING"] = true,
      ["ITEM_MOD_DODGE_RATING"] = true,
      ["ITEM_MOD_PARRY_RATING"] = true,
      ["ITEM_MOD_BLOCK_RATING"] = true,
      ["ITEM_MOD_HIT_SPELL_RATING"] = true,
      ["ITEM_MOD_CRIT_SPELL_RATING"] = true,
      ["ITEM_MOD_HASTE_SPELL_RATING"] = true,
      ["ITEM_MOD_HIT_RATING"] = true,
      ["ITEM_MOD_CRIT_RATING"] = true,
      ["ITEM_MOD_HASTE_RATING"] = true,
      ["ITEM_MOD_EXPERTISE_RATING"] = true,
      ["ITEM_MOD_HIT_MELEE_RATING"] = true,
      ["ITEM_MOD_HIT_RANGED_RATING"] = true,
      ["ITEM_MOD_CRIT_MELEE_RATING"] = true,
      ["ITEM_MOD_CRIT_RANGED_RATING"] = true,
      ["ITEM_MOD_AGILITY"] = true,
      ["Agility-Crit"] = true,
      ["Agility-AP"] = false,
      ["Agility-RAP"] = false,
      ["Agility-Armor"] = false,
   },
};


LB_Config = nil;


LB_CONF_STR = _locale.ConfigStrings;

local _currentTogglesState = {
   ["ITEM_MOD_DEFENSE_SKILL_RATING"] = true,
   ["ITEM_MOD_DODGE_RATING"] = true,
   ["ITEM_MOD_PARRY_RATING"] = true,
   ["ITEM_MOD_BLOCK_RATING"] = true,
   ["ITEM_MOD_HIT_SPELL_RATING"] = true,
   ["ITEM_MOD_CRIT_SPELL_RATING"] = true,
   ["ITEM_MOD_HASTE_SPELL_RATING"] = true,
   ["ITEM_MOD_HIT_RATING"] = true,
   ["ITEM_MOD_CRIT_RATING"] = true,
   ["ITEM_MOD_HASTE_RATING"] = true,
   ["ITEM_MOD_EXPERTISE_RATING"] = true,
   ["ITEM_MOD_HIT_MELEE_RATING"] = true,
   ["ITEM_MOD_HIT_RANGED_RATING"] = true,
   ["ITEM_MOD_CRIT_MELEE_RATING"] = true,
   ["ITEM_MOD_CRIT_RANGED_RATING"] = true,
   ["ITEM_MOD_AGILITY"] = true,
   ["Agility-Dodge"] = false,
   ["Agility-Crit"] = true,
   ["Agility-AP"] = false,
   ["Agility-RAP"] = false,
   ["Agility-Armor"] = false,
};

local function drawCurrentState()

   LB_DefenseRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_DEFENSE_SKILL_RATING"]);
   LB_DodgeRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_DODGE_RATING"]);
   LB_ParryRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_PARRY_RATING"]);
   LB_BlockRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_BLOCK_RATING"]);


   LB_SpellHitRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_HIT_SPELL_RATING"]);
   LB_SpellCritRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_CRIT_SPELL_RATING"]);
   LB_SpellHasteRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_HASTE_SPELL_RATING"]);


   LB_PhysicalHitRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_HIT_RATING"]);
   LB_PhysicalCritRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_CRIT_RATING"]);
   LB_PhysicalHasteRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_HASTE_RATING"]);
   LB_PhysicalExpertiseRatingCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_EXPERTISE_RATING"]);



   LB_AgilityCheckbox:SetChecked(_currentTogglesState["ITEM_MOD_AGILITY"]);
   local agilityChecked = LB_AgilityCheckbox:GetChecked();

   LB_AgilityDodgeCheckbox:SetChecked(_currentTogglesState["Agility-Dodge"]);
   LB_AgilityDodgeCheckbox:SetEnabled(agilityChecked);
   LB_AgilityCritCheckbox:SetChecked(_currentTogglesState["Agility-Crit"])
   LB_AgilityCritCheckbox:SetEnabled(agilityChecked);
   LB_AgilityAPCheckbox:SetChecked(_currentTogglesState["Agility-AP"]);
   LB_AgilityAPCheckbox:SetEnabled(agilityChecked);
   LB_AgilityRAPCheckbox:SetChecked(_currentTogglesState["Agility-RAP"]);
   LB_AgilityRAPCheckbox:SetEnabled(agilityChecked);
   LB_AgilityArmorCheckbox:SetChecked(_currentTogglesState["Agility-Armor"]);
   LB_AgilityArmorCheckbox:SetEnabled(agilityChecked);

end

function LB_Config_CheckButtonChanged(_, statKey, isChecked)

   _currentTogglesState[statKey] = isChecked;
   drawCurrentState();
end

local function configFrame_OnRefresh(_)


   for k, v in pairs(LB.Config.DisplayToggles) do
      _currentTogglesState[k] = v;
   end
   drawCurrentState();
end

local function configFrame_OnOkay(_)
   for k, v in pairs(_currentTogglesState) do
      LB.Config.DisplayToggles[k] = v;
      LB_Config.DisplayToggles[k] = v;
   end
end

local function configFrame_OnCancel(_)

   for k, v in pairs(LB.Config.DisplayToggles) do
      _currentTogglesState[k] = v;
   end
end

local function configFrame_OnDefault(_)

   for k, v in pairs(_defaultConfig.DisplayToggles) do
      _currentTogglesState[k] = v;
      LB_Config.DisplayToggles[k] = v;
      LB.Config.DisplayToggles[k] = v;
   end
   drawCurrentState();
end

local function loadCompleted(configFrame)
   configFrame.name = "Little Buster";
   configFrame.okay = configFrame_OnOkay;
   configFrame.cancel = configFrame_OnCancel;
   configFrame.refresh = configFrame_OnRefresh;
   configFrame.default = configFrame_OnDefault;


   if (not LB_Config) then
      LB_Config = _defaultConfig;
   end



   for k, v in pairs(_defaultConfig) do
      if (LB_Config)[k] == nil then
         (LB_Config)[k] = v;
      end
   end

   for k, v in pairs(_defaultConfig.DisplayToggles) do
      if LB_Config.DisplayToggles[k] == nil then
         LB_Config.DisplayToggles[k] = v;
      end
   end
   LB.Config = LB_Config;

   InterfaceOptions_AddCategory(configFrame);
end

function LB_ConfigRootFrame_OnEvent(self, _, ...)

   local addonName = ...;
   if (addonName == "LittleBuster") then
      loadCompleted(self);
   end
end

function LB_ConfigRootFrame_OnLoad(self)
   self:RegisterEvent("ADDON_LOADED");
end
